#
# spec file for package python3-wheel
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-wheel
Version:        0.29.0
Release:        2.2
Summary:        A built-package format for Python
License:        MIT
Group:          Development/Languages/Python
Url:            https://bitbucket.org/pypa/wheel
Source:         https://files.pythonhosted.org/packages/source/w/wheel/wheel-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# Test requirements:
BuildRequires:  python3-jsonschema
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-cov
Recommends:     python3-ed25519ll
Recommends:     python3-dirspec
Recommends:     python3-keyring
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch

%description
A built-package format for Python.

A wheel is a ZIP-format archive with a specially formatted filename
and the .whl extension. It is designed to contain all the files for a
PEP 376 compatible install in a way that is very close to the on-disk
format. Many packages will be properly installed with only the "Unpack"
step (simply extracting the file onto sys.path), and the unpacked archive
preserves enough information to "Spread" (copy data and scripts to their
final locations) at any later time.

The wheel project provides a bdist_wheel command for setuptools
(requires distribute >= 0.6.34). Wheel files can be
installed with a newer pip from https://github.com/pypa/pip
or with wheel's own command line utility.

The wheel documentation is at http://wheel.rtfd.org/. The
file format is documented in PEP 427
(http://www.python.org/dev/peps/pep-0427/).

The reference implementation is at http://bitbucket.org/dholth/wheel/

%prep
%setup -q -n wheel-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for b in wheel ; do
  mv %{buildroot}%{_bindir}/$b %{buildroot}%{_bindir}/$b-%{py3_ver}
  touch %{buildroot}%{_sysconfdir}/alternatives/$b
  ln -sf %{_sysconfdir}/alternatives/$b %{buildroot}/%{_bindir}/$b
done

%check
python3 setup.py test

%post
update-alternatives --install %{_bindir}/wheel wheel %{_bindir}/wheel-%{py3_ver} 30

%postun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove wheel %{_bindir}/wheel-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc CHANGES.txt README.txt LICENSE.txt
%{_bindir}/wheel
%{_bindir}/wheel-%{py3_ver}
%ghost %{_sysconfdir}/alternatives/wheel
%{python3_sitelib}/wheel-%{version}-py%{py3_ver}.egg-info
%{python3_sitelib}/wheel/

%changelog
* Mon Jun 13 2016 toddrme2178@gmail.com
- Remove unneeded test requirements.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sat Feb  6 2016 arun@gmx.de
- update to version 0.29.0:
  * Fix compression type of files in archive (Issue #155, Pull Request
    [#62], thanks Xavier Fernandez)
* Sat Feb  6 2016 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.28.0:
  * Fix file modes in archive (Issue #154)
- changes from version 0.27.0:
  * Support forcing a platform tag using `--plat-name` on pure-Python
    wheels, as well as nonstandard platform tags on non-pure wheels
    (Pull Request #60, Issue #144, thanks Andrés Díaz)
  * Add SOABI tags to platform-specific wheels built for Python 2.X
    (Pull Request #55, Issue #63, Issue #101)
  * Support reproducible wheel files, wheels that can be rebuilt and
    will hash to the same values as previous builds (Pull Request #52,
    Issue #143, thanks Barry Warsaw)
  * Support for changes in keyring >= 8.0 (Pull Request #61, thanks
    Jason R. Coombs)
  * Use the file context manager when checking if dependency_links.txt
    is empty, fixes problems building wheels under PyPy on Windows
    (Issue #150, thanks Cosimo Lupo)
  * Don't attempt to (recursively) create a build directory ending
    with `..` (invalid on all platforms, but code was only executed on
    Windows) (Issue #91)
  * Added the PyPA Code of Conduct (Pull Request #56)
* Sun Sep 27 2015 arun@gmx.de
- specfile:
  * update copyright year
  * update url
- update to version 0.26.0:
  * Fix multiple entrypoint comparison failure on Python 3 (Issue #148)
- changes from version 0.25.0:
  * Add Python 3.5 to tox configuration
  * Deterministic (sorted) metadata
  * Fix tagging for Python 3.5 compatibility
  * Support py2-none-'arch' and py3-none-'arch' tags
  * Treat data-only wheels as pure
  * Write to temporary file and rename when using wheel install --force
* Wed Dec  3 2014 arun@gmx.de
- specfile: removed wininst2wheel and egg2wheel, since they are not in 0.24.0 anymore
- update to version 0.24.0:
  * The python tag used for pure-python packages is now .pyN (major version
    only). This change actually occurred in 0.23.0 when the --python-tag
    option was added, but was not explicitly mentioned in the changelog then.
  * wininst2wheel and egg2wheel removed. Use "wheel convert [archive]"
    instead.
  * Wheel now supports setuptools style conditional requirements via the
    extras_require={} syntax. Separate 'extra' names from conditions using
    the : character. Wheel's own setup.py does this. (The empty-string
    extra is the same as install_requires.) These conditional requirements
    should work the same whether the package is installed by wheel or
    by setup.py.
- changes from 0.23.0:
  * Compatibiltiy tag flags added to the bdist_wheel command
  * sdist should include files necessary for tests
  * 'wheel convert' can now also convert unpacked eggs to wheel
  * Rename pydist.json to metadata.json to avoid stepping on the PEP
  * The --skip-scripts option has been removed, and not generating scripts is now
    the default. The option was a temporary approach until installers could
    generate scripts themselves. That is now the case with pip 1.5 and later.
    Note that using pip 1.4 to install a wheel without scripts will leave the
    installation without entry-point wrappers. The "wheel install-scripts"
    command can be used to generate the scripts in such cases.
  * Thank you contributors
* Mon Feb 10 2014 speilicke@suse.com
- Drop requirement on python3-argparse
- Fixed update-alternatives usage
* Thu Feb  6 2014 speilicke@suse.com
- Initial version
